@@ -18,23 +18,21 @@ mlb_metrics <- function(){
   mlb_endpoint <- httr::modify_url(mlb_endpoint, query = query_params)
   
   tryCatch(
-    expr={
+    expr = {
       resp <- mlb_endpoint %>% 
         mlb_api_call()
       metrics <- jsonlite::fromJSON(jsonlite::toJSON(resp), flatten = TRUE)  %>% 
         janitor::clean_names() %>% 
         as.data.frame() %>% 
         dplyr::rename(
-          metric_name = .data$name,
-          stat_group = .data$group,
-          metric_unit = .data$unit) %>%
+          "metric_name" = "name",
+          "stat_group" = "group",
+          "metric_unit" = "unit") %>%
         make_baseballr_data("MLB Metrics data from MLB.com",Sys.time())
     },
     error = function(e) {
       message(glue::glue("{Sys.time()}: Invalid arguments provided"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
