@@ -16,22 +16,20 @@ mlb_pitch_types <- function(){
   mlb_endpoint <- httr::modify_url(mlb_endpoint, query = query_params)
   
   tryCatch(
-    expr={
+    expr = {
       resp <- mlb_endpoint %>% 
         mlb_api_call()
       pitch_types <- jsonlite::fromJSON(jsonlite::toJSON(resp), flatten = TRUE)  %>% 
         janitor::clean_names() %>% 
         as.data.frame() %>% 
         dplyr::rename(
-          pitch_type_code = .data$code,
-          pitch_type_description = .data$description) %>%
+          "pitch_type_code" = "code",
+          "pitch_type_description" = "description") %>%
         make_baseballr_data("MLB Pitch Types data from MLB.com",Sys.time())
     },
     error = function(e) {
       message(glue::glue("{Sys.time()}: Invalid arguments provided"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
