@@ -16,23 +16,21 @@ mlb_player_status_codes <- function(){
   mlb_endpoint <- httr::modify_url(mlb_endpoint, query = query_params)
   
   tryCatch(
-    expr={
+    expr = {
       resp <- mlb_endpoint %>% 
         mlb_api_call()
       player_status_codes <- jsonlite::fromJSON(jsonlite::toJSON(resp), flatten = TRUE)  %>% 
         janitor::clean_names() %>% 
         as.data.frame() %>% 
         dplyr::rename(
-          player_status_code = .data$code,
-          player_status_description = .data$description) %>%
+          "player_status_code" = "code",
+          "player_status_description" = "description") %>%
         make_baseballr_data("MLB Player Status Codes data from MLB.com",Sys.time())
       
     },
     error = function(e) {
       message(glue::glue("{Sys.time()}: Invalid arguments provided"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
