@@ -16,15 +16,15 @@ mlb_review_reasons <- function(){
   mlb_endpoint <- httr::modify_url(mlb_endpoint, query = query_params)
   
   tryCatch(
-    expr={
+    expr = {
       resp <- mlb_endpoint %>% 
         mlb_api_call()
       review_reasons <- jsonlite::fromJSON(jsonlite::toJSON(resp), flatten = TRUE)  %>% 
         janitor::clean_names() %>% 
         as.data.frame() %>% 
         dplyr::rename(
-          review_reason_code = .data$code,
-          review_reason_description = .data$description
+          "review_reason_code" = "code",
+          "review_reason_description" = "description"
         ) %>%
         make_baseballr_data("MLB Review Reasons data from MLB.com",Sys.time())
       
@@ -32,8 +32,6 @@ mlb_review_reasons <- function(){
     error = function(e) {
       message(glue::glue("{Sys.time()}: Invalid arguments provided"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
