@@ -124,92 +124,92 @@ cols <- c(
   "SIERA",
   "RS_9",
   "E-F",
-  "FA_pct (sc)",
-  "FT_pct (sc)",
-  "FC_pct (sc)",
-  "FS_pct (sc)",
-  "FO_pct (sc)",
-  "SI_pct (sc)",
-  "SL_pct (sc)",
-  "CU_pct (sc)",
-  "KC_pct (sc)",
-  "EP_pct (sc)",
-  "CH_pct (sc)",
-  "SC_pct (sc)",
-  "KN_pct (sc)",
-  "UN_pct (sc)",
-  "vFA (sc)",
-  "vFT (sc)",
-  "vFC (sc)",
-  "vFS (sc)",
-  "vFO (sc)",
-  "vSI (sc)",
-  "vSL (sc)",
-  "vCU (sc)",
-  "vKC (sc)",
-  "vEP (sc)",
-  "vCH (sc)",
-  "vSC (sc)",
-  "vKN (sc)",
-  "FA-X (sc)",
-  "FT-X (sc)",
-  "FC-X (sc)",
-  "FS-X (sc)",
-  "FO-X (sc)",
-  "SI-X (sc)",
-  "SL-X (sc)",
-  "CU-X (sc)",
-  "KC-X (sc)",
-  "EP-X (sc)",
-  "CH-X (sc)",
-  "SC-X (sc)",
-  "KN-X (sc)",
-  "FA-Z (sc)",
-  "FT-Z (sc)",
-  "FC-Z (sc)",
-  "FS-Z (sc)",
-  "FO-Z (sc)",
-  "SI-Z (sc)",
-  "SL-Z (sc)",
-  "CU-Z (sc)",
-  "KC-Z (sc)",
-  "EP-Z (sc)",
-  "CH-Z (sc)",
-  "SC-Z (sc)",
-  "KN-Z (sc)",
-  "wFA (sc)",
-  "wFT (sc)",
-  "wFC (sc)",
-  "wFS (sc)",
-  "wFO (sc)",
-  "wSI (sc)",
-  "wSL (sc)",
-  "wCU (sc)",
-  "wKC (sc)",
-  "wEP (sc)",
-  "wCH (sc)",
-  "wSC (sc)",
-  "wKN (sc)",
-  "wFA_C (sc)",
-  "wFT_C (sc)",
-  "wFC_C (sc)",
-  "wFS_C (sc)",
-  "wFO_C (sc)",
-  "wSI_C (sc)",
-  "wSL_C (sc)",
-  "wCU_C (sc)",
-  "wKC_C (sc)",
-  "wEP_C (sc)",
-  "wCH_C (sc)",
-  "wSC_C (sc)",
-  "wKN_C (sc)",
-  "O-Swing_pct (sc)",
-  "Z-Swing_pct (sc)",
-  "Swing_pct (sc)",
-  "O-Contact_pct (sc)",
-  "Z-Contact_pct (sc)",
-  "Contact_pct (sc)",
-  "Zone_pct (sc)",
+  "FA_pct_(sc)",
+  "FT_pct_(sc)",
+  "FC_pct_(sc)",
+  "FS_pct_(sc)",
+  "FO_pct_(sc)",
+  "SI_pct_(sc)",
+  "SL_pct_(sc)",
+  "CU_pct_(sc)",
+  "KC_pct_(sc)",
+  "EP_pct_(sc)",
+  "CH_pct_(sc)",
+  "SC_pct_(sc)",
+  "KN_pct_(sc)",
+  "UN_pct_(sc)",
+  "vFA_(sc)",
+  "vFT_(sc)",
+  "vFC_(sc)",
+  "vFS_(sc)",
+  "vFO_(sc)",
+  "vSI_(sc)",
+  "vSL_(sc)",
+  "vCU_(sc)",
+  "vKC_(sc)",
+  "vEP_(sc)",
+  "vCH_(sc)",
+  "vSC_(sc)",
+  "vKN_(sc)",
+  "FA-X_(sc)",
+  "FT-X_(sc)",
+  "FC-X_(sc)",
+  "FS-X_(sc)",
+  "FO-X_(sc)",
+  "SI-X_(sc)",
+  "SL-X_(sc)",
+  "CU-X_(sc)",
+  "KC-X_(sc)",
+  "EP-X_(sc)",
+  "CH-X_(sc)",
+  "SC-X_(sc)",
+  "KN-X_(sc)",
+  "FA-Z_(sc)",
+  "FT-Z_(sc)",
+  "FC-Z_(sc)",
+  "FS-Z_(sc)",
+  "FO-Z_(sc)",
+  "SI-Z_(sc)",
+  "SL-Z_(sc)",
+  "CU-Z_(sc)",
+  "KC-Z_(sc)",
+  "EP-Z_(sc)",
+  "CH-Z_(sc)",
+  "SC-Z_(sc)",
+  "KN-Z_(sc)",
+  "wFA_(sc)",
+  "wFT_(sc)",
+  "wFC_(sc)",
+  "wFS_(sc)",
+  "wFO_(sc)",
+  "wSI_(sc)",
+  "wSL_(sc)",
+  "wCU_(sc)",
+  "wKC_(sc)",
+  "wEP_(sc)",
+  "wCH_(sc)",
+  "wSC_(sc)",
+  "wKN_(sc)",
+  "wFA_C_(sc)",
+  "wFT_C_(sc)",
+  "wFC_C_(sc)",
+  "wFS_C_(sc)",
+  "wFO_C_(sc)",
+  "wSI_C_(sc)",
+  "wSL_C_(sc)",
+  "wCU_C_(sc)",
+  "wKC_C_(sc)",
+  "wEP_C_(sc)",
+  "wCH_C_(sc)",
+  "wSC_C_(sc)",
+  "wKN_C_(sc)",
+  "O-Swing_pct_(sc)",
+  "Z-Swing_pct_(sc)",
+  "Swing_pct_(sc)",
+  "O-Contact_pct_(sc)",
+  "Z-Contact_pct_(sc)",
+  "Contact_pct_(sc)",
+  "Zone_pct_(sc)",
   "Pace",
   "RA9-WAR",
   "BIP-Wins",
